Calculators
===========

.. toctree::
  :maxdepth: 1

  MMFFEnergy <_autosummary/stko.MMFFEnergy>
  UFFEnergy <_autosummary/stko.UFFEnergy>
  OpenBabelEnergy <_autosummary/stko.OpenBabelEnergy>
  OpenMMEnergy <_autosummary/stko.OpenMMEnergy>
  XTBEnergy <_autosummary/stko.XTBEnergy>
  OrcaEnergy <_autosummary/stko.OrcaEnergy>
  RmsdCalculator <_autosummary/stko.RmsdCalculator>
  RmsdMappedCalculator <_autosummary/stko.RmsdMappedCalculator>
  KabschRmsdCalculator <_autosummary/stko.KabschRmsdCalculator>
  ShapeCalculator <_autosummary/stko.ShapeCalculator>
  TorsionCalculator <_autosummary/stko.TorsionCalculator>
  ConstructedMoleculeTorsionCalculator <_autosummary/stko.ConstructedMoleculeTorsionCalculator>
  MatchedTorsionCalculator <_autosummary/stko.MatchedTorsionCalculator>
  PlanarityCalculator <_autosummary/stko.PlanarityCalculator>
  GeometryAnalyser <_autosummary/stko.molecule_analysis.GeometryAnalyser>
